# package hello world

[How to Build Your Very First Python Package](https://www.freecodecamp.org/news/build-your-first-python-package/)

- 介绍了如何制作python lib库
- 编译出来的包，的确包含了目录 pypkagemodule 子目录和setup文件

## 优化

[An Introduction to Distutils](https://docs.python.org/3/distutils/introduction.html#distutils-simple-example)

[Writing the Setup Script](https://docs.python.org/3/distutils/setupscript.html)

- 优化了导出设置，可以导出子目录，以及根目录下的文件
